<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Sortable Table</title>
    <!-- MDB CSS -->
    <link
      href="https://cdnjs.cloudflare.com/ajax/libs/mdb-ui-kit/3.10.2/mdb.min.css"
      rel="stylesheet"
    />
    <!-- SortableJS CSS (optional for additional styles) -->
    <style>
        body {
            padding-top: 15px;
        }
        .table-row {
            cursor: move;
        }
        .fixed-button-container {
            position: fixed;
            bottom: 20px;
            left: 50%;
            transform: translateX(-50%);
            z-index: 1000;
            display: flex;
            gap: 10px;
        }
        .center-content {
            text-align: center;
            margin-bottom: 20px;
        }
        .select-container {
            display: flex;
            justify-content: center;
            gap: 10px;
            margin-bottom: 20px;
        }
        select {
            width: 180px;
        }
        .table-container {
            max-width: 750px;
            margin: 0 auto;
        }
    </style>
</head>
<body>
    <div class="container mt-3">
        <div class="center-content">
            <h4>Sortable Table of Users</h4>
        </div>
        <div class="select-container">
            <select name="visaType" id="visaType">
                <option value="">-- Select a Visa Type --</option>
                <option value="F1 Fresher">F1 Fresher</option>
                <option value="F1 Refused">F1 Refused</option>
                <option value="B1/B2">B1/B2</option>
            </select>
            <select name="priority" id="priority">
                <option value="">-- Select a Priority --</option>
                <option value="all">All</option>
                <option value="top priority">Top Most Priority</option>
                <option value="high priority">High Priority</option>
                <option value="normal">Normal</option>
            </select>
        </div>
        <div class="table-container">
            <table class="table">
                <thead>
                    <tr>
                        <th scope="col" style="font-weight: bold;">Name</th>
                        <th scope="col" style="font-weight: bold;">Visa Type</th>
                        <th scope="col" style="font-weight: bold;">OFC</th>
                        <th scope="col" style="font-weight: bold;">VI</th>
                        <th scope="col" style="font-weight: bold;">Time</th>
                    </tr>
                </thead>
                <tbody id="sortable-table">
                    <!-- Dynamic rows will be populated here based on selection -->
                </tbody>
            </table>
        </div>
    </div>

    <div class="fixed-button-container">
        <button type="button" class="btn btn-secondary" onclick="window.history.back();">Back</button>
        <button type="button" class="btn btn-primary" onclick="saveData()">Save</button>
    </div>

    <!-- MDB JavaScript -->
    <script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/mdb-ui-kit/3.10.2/mdb.min.js"></script>
    <!-- SortableJS JavaScript -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/Sortable/1.14.0/Sortable.min.js"></script>
    <script>
        const data = {
            'B1/B2': {
                'top priority': [
                    ['ayeshahussaine', 'B1/B2', 'Hyd', 'Hyd', 'Jun-Jul'],
                    ['mohammedahmed100', 'B1/B2', 'Hyd', 'Hyd', 'May-Jun'],
                    ['rajvats99', 'B1/B2', 'Del', 'Del', 'May-Jun']
                ],
                'high priority': [
                    ['SapaS1970', 'B1/B2', 'Mum/Del', 'Mum/Del', 'May-Jul'],
                    ['pprathibha738', 'B1/B2', 'Che/Hyd', 'Che/Hyd', 'May-Jul']
                ],
                'normal': [
                    ['asiyab536', 'B1/B2', 'Any', 'Any', 'Jul'],
                    ['adityakaundinya', 'B1/B2', 'Any', 'Any', 'Jun-Jul']
                ]
            },
            'F1 Fresher': {
                'top priority': [
                    ['amritasingh17304', 'F1', 'Mum', 'Mum', 'Jun 25-Jul 5'],
                    ['Rama', 'F1', 'Mum', 'Mum', 'Jun 25-Jul 5']
                ],
                'high priority': [
                    ['amritasingh17304', 'F1', 'Mum', 'Mum', 'Jun 25-Jul 5'],
                    ['vela', 'F1', 'Mum', 'Mum', 'Jun 25-Jul 5']
                ],
                'normal': [
                    ['amritasingh17304', 'F1', 'Mum', 'Mum', 'Jun 25-Jul 5'],
                    ['Raju', 'F1', 'Mum', 'Mum', 'Jun 25-Jul 5']
                ]
            },
            'F1 Refused': {
                'top priority': [
                    ['Vvel', 'F1 Ref', 'Mum', 'Mum', 'Jun 25-Jul 5'],
                    ['Hari', 'F1 Ref', 'Mum', 'Mum', 'Jun 25-Jul 5']
                ],
                'high priority': [
                    ['Gow', 'F1 Ref', 'Mum', 'Mum', 'Jun 25-Jul 5'],
                    ['Renu', 'F1 Ref', 'Mum', 'Mum', 'Jun 25-Jul 5']
                ],
                'normal': [
                    ['Kanmani17304', 'F1 Ref', 'Mum', 'Mum', 'Jun 25-Jul 5'],
                    ['Kathija', 'F1 Ref', 'Mum', 'Mum', 'Jun 25-Jul 5']
                ]
            }
        };

        const visaTypeSelect = document.getElementById('visaType');
        const prioritySelect = document.getElementById('priority');
        const tableBody = document.getElementById('sortable-table');

        visaTypeSelect.addEventListener('change', populateTable);
        prioritySelect.addEventListener('change', populateTable);

        function populateTable() {
            const visaType = visaTypeSelect.value;
            const priority = prioritySelect.value;
            
            if (visaType) {
                let rows = [];
                if (priority === 'all') {
                    for (let pri in data[visaType]) {
                        rows = rows.concat(data[visaType][pri]);
                    }
                } else if (priority) {
                    rows = data[visaType][priority];
                }
                tableBody.innerHTML = '';
                rows.forEach(row => {
                    const tr = document.createElement('tr');
                    tr.className = 'table-row';
                    row.forEach(cell => {
                        const td = document.createElement('td');
                        td.textContent = cell;
                        tr.appendChild(td);
                    });
                    tableBody.appendChild(tr);
                });

                new Sortable(tableBody, {
                    animation: 150,
                    ghostClass: 'blue-background-class'
                });
            }
        }

        function saveData() {
            const rows = Array.from(tableBody.querySelectorAll('tr')).map(tr => 
                Array.from(tr.querySelectorAll('td')).map(td => td.textContent)
            );

            // Here you can send the rows data to the server or handle it as needed
            console.log('Saved Data:', rows);
            alert('Data saved successfully!');
        }
    </script>
</body>
</html>
