<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Interactive Calendar</title>
  <!-- Add Bootstrap Icons CDN for arrow icons -->
  <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-icons/1.8.1/font/bootstrap-icons.min.css">
  <style>
    body {
      position: relative;
      display: flex;
      justify-content: center;
      align-items: center;
      height: 100vh;
      font-family: 'Poppins', sans-serif;
      background-color: #f0f0f0;
    }

    .calendar-container {
      display: flex;
      background-color: #fff;
      border-radius: 5px;
      overflow: hidden;
    }

    .calendar {
      padding: 10px;
    }

    .calendar__controls {
      display: flex;
      justify-content: center;
      align-items: center;
      margin-bottom: 10px;
      background-color: #d3d3d3;
      padding: 5px;
      border-radius: 3px;
      position: relative;
    }

    .calendar__controls button {
      background: none;
      border: none;
      font-size: 1.2em;
      cursor: pointer;
      position: absolute;
    }

    .calendar__prev-month {
      left: 0;
    }

    .calendar__next-month {
      right: 0;
    }

    .calendar__controls select,
    .calendar__current-date {
      font-size: 1em;
      font-weight: bold;
      text-align: center;
    }

    .calendar__controls select {
      margin: 0 2px;
    }

    .calendar__date {
      display: grid;
      grid-template-columns: repeat(7, 1fr);
      grid-gap: 0;
      margin-top: 10px;
    }

    .calendar__day,
    .calendar__number {
      display: flex;
      align-items: center;
      justify-content: center;
      width: 40px;
      height: 40px;
      color: #262626;
    }

    .calendar__number {
      border: 1px solid #ccc;
    }

    .calendar__number.green {
      border: 2px solid #28a745;
      cursor: pointer;
    }

    .calendar__number.red {
      border: 1px solid lightcoral;
    }

    .calendar__number.blue {
      background-color: #007bff;
      color: #fff;
      border-color: #007bff;
    }

    .calendar__number.empty {
      display: none;
    }

    .calendar__current-date {
      text-align: center;
      width: 100%;
    }
  </style>
</head>
<body>
  <div class="calendar-container">
    <div class="calendar">
      <div class="calendar__controls">
        <button class="calendar__prev-month"><i class="bi bi-caret-left-fill"></i></button>
        <select id="month-select1"></select>
        <select id="year-select1"></select>
      </div>
      <div class="calendar__date">
        <div class="calendar__day">Su</div>
        <div class="calendar__day">Mo</div>
        <div class="calendar__day">Tu</div>
        <div class="calendar__day">We</div>
        <div class="calendar__day">Th</div>
        <div class="calendar__day">Fr</div>
        <div class="calendar__day">Sa</div>
      </div>
      <div class="calendar__date" id="dates1">
        <!-- Dates for first month will be generated here -->
      </div>
    </div>

    <div class="calendar">
      <div class="calendar__controls">
        <span class="calendar__current-date" id="month2"></span>
        <button class="calendar__next-month"><i class="bi bi-caret-right-fill"></i></button>
      </div>
      <div class="calendar__date">
        <div class="calendar__day">Su</div>
        <div class="calendar__day">Mo</div>
        <div class="calendar__day">Tu</div>
        <div class="calendar__day">We</div>
        <div class="calendar__day">Th</div>
        <div class="calendar__day">Fr</div>
        <div class="calendar__day">Sa</div>
      </div>
      <div class="calendar__date" id="dates2">
        <!-- Dates for second month will be generated here -->
      </div>
    </div>
  </div>

  <script>
    document.addEventListener('DOMContentLoaded', () => {
      const months = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
      let currentYear = new Date().getFullYear();
      let currentMonth = new Date().getMonth();
      let currentDate = new Date().getDate();
      let selectedDateElement = null;

      const updateDropdowns = () => {
        const monthSelect1 = document.getElementById('month-select1');
        const yearSelect1 = document.getElementById('year-select1');

        monthSelect1.innerHTML = '';
        yearSelect1.innerHTML = '';

        months.forEach((month, index) => {
          let option = document.createElement('option');
          option.value = index;
          option.textContent = month;
          if (index === currentMonth) option.selected = true;
          monthSelect1.appendChild(option);
        });

        for (let year = currentYear - 10; year <= currentYear + 10; year++) {
          let option = document.createElement('option');
          option.value = year;
          option.textContent = year;
          if (year === currentYear) option.selected = true;
          yearSelect1.appendChild(option);
        }
      };

      const updateCalendar = () => {
        const dates1El = document.getElementById('dates1');
        const dates2El = document.getElementById('dates2');

        let month1 = currentMonth;
        let month2 = (currentMonth + 1) % 12;
        let year2 = month1 === 11 ? currentYear + 1 : currentYear;

        generateDates(dates1El, month1, currentYear);
        generateDates(dates2El, month2, year2);

        document.getElementById('month2').textContent = `${months[month2]} ${year2}`;
      };

      const generateDates = (datesEl, month, year) => {
        datesEl.innerHTML = '';
        let firstDay = new Date(year, month, 1).getDay();
        let daysInMonth = new Date(year, month + 1, 0).getDate();
        let days = Array(firstDay).fill('').concat([...Array(daysInMonth).keys()].map(i => i + 1));

        days.forEach(day => {
          const dayEl = document.createElement('div');
          dayEl.className = 'calendar__number';
          if (day !== '') {
            const date = new Date(year, month, day);
            if (year < currentYear || (year === currentYear && (month < currentMonth || (month === currentMonth && day < currentDate)))) {
              dayEl.classList.add('red');
            } else if (Math.random() > 0.7) {
              dayEl.classList.add('green');
            } else {
              dayEl.classList.add('red');
            }
          } else {
            dayEl.classList.add('empty');
          }
          dayEl.textContent = day;
          datesEl.appendChild(dayEl);
        });

        const greenNumbers = datesEl.querySelectorAll('.calendar__number.green');
        greenNumbers.forEach(date => {
          date.addEventListener('click', () => {
            if (selectedDateElement) {
              selectedDateElement.classList.remove('blue');
            }
            selectedDateElement = date;
            date.classList.add('blue');
          });
        });
      };

      const getStartDayOfMonth = (month, year) => {
        let previousMonth = month === 0 ? 11 : month - 1;
        let previousYear = month === 0 ? year - 1 : year;
        let lastDayOfPreviousMonth = new Date(previousYear, previousMonth + 1, 0).getDay();
        return (lastDayOfPreviousMonth + 1) % 7;
      };

      const navigateMonth = (direction) => {
        if (direction === 'prev') {
          if (currentMonth === 0) {
            currentMonth = 11;
            currentYear--;
          } else {
            currentMonth--;
          }
        } else if (direction === 'next') {
          if (currentMonth === 11) {
            currentMonth = 0;
            currentYear++;
          } else {
            currentMonth++;
          }
        }
        updateDropdowns();
        updateCalendar();
      };

      document.querySelector('.calendar__prev-month').addEventListener('click', () => navigateMonth('prev'));
      document.querySelector('.calendar__next-month').addEventListener('click', () => navigateMonth('next'));

      document.getElementById('month-select1').addEventListener('change', (event) => {
        currentMonth = parseInt(event.target.value);
        updateCalendar();
      });

      document.getElementById('year-select1').addEventListener('change', (event) => {
        currentYear = parseInt(event.target.value);
        updateCalendar();
      });

      updateDropdowns();
      updateCalendar();
    });
  </script>
</body>
</html>
